import { m as mapGetters } from "../../vendor/vendor-core.2a9962eb.js";
import { C as formatCurrency } from "../../app.9a8150b2.js";
import { n as normalizeComponent } from "../../_plugin-vue2_normalizer.7b9a2fe2.js";
import "../../vendor/vendor-others.d4f8aae2.js";
import "../../vendor/vendor-essential.31dae676.js";
import "../../vendor/vendor-bootstrap-vue.397f83c5.js";
import "../../vendor/vendor-vue-gtag.137cb49d.js";
const BaseInput_vue_vue_type_style_index_0_scoped_bb5ed607_lang = "";
const _sfc_main = {
  inheritAttrs: false,
  name: "base-input",
  props: {
    required: {
      type: Boolean,
      description: "Whether input is required (adds an asterix *)"
    },
    valid: {
      type: Boolean,
      description: "Whether is valid",
      default: void 0
    },
    size: {
      type: String,
      default: ""
    },
    alternative: {
      type: Boolean,
      description: "Whether input is of alternative layout"
    },
    native: {
      type: Boolean,
      description: "Whether input is of material layout"
    },
    label: {
      type: String,
      description: "Input label (text before input)"
    },
    error: {
      type: String,
      description: "Input error (below input)"
    },
    wrapperClasses: {
      type: String,
      description: "Input label css classes"
    },
    labelClasses: {
      type: String,
      description: "Input label css classes"
    },
    inputClasses: {
      type: String,
      description: "Input css classes"
    },
    value: {
      type: [Object, Array, String, Number, Boolean],
      description: "Input value"
    },
    addonRightIcon: {
      type: String,
      description: "Addon right icon"
    },
    addonLeftIcon: {
      type: String,
      description: "Addont left icon"
    },
    addonRightText: {
      type: String,
      description: "Addon right text"
    },
    addonLeftText: {
      type: String,
      description: "Addont left text"
    },
    format: {
      type: String,
      description: "lowercase/uppercase/capitalize/sentence",
      default: ""
    },
    formatOn: {
      type: String,
      default: "blur"
    },
    autoFocus: {
      type: Boolean,
      description: "if autofocus is on",
      default: void 0
    },
    selectOnFocus: {
      type: Boolean,
      description: "if select on focus is on",
      default: void 0
    },
    scrollIfFocused: {
      type: Boolean,
      description: "if scroll if focused is on",
      default: true
    },
    translateOnBlur: {
      type: Boolean,
      description: "if translate on blur is on",
      default: void 0
    },
    isWrapper: {
      type: Boolean,
      default: false
    },
    allowEmpty: {
      type: Boolean,
      default: true
    },
    naked: {
      type: Boolean,
      default: false
    },
    hidePrefixSuffix: {
      type: Boolean,
      default: false
    },
    currency: {
      type: Object,
      default: null
    }
  },
  data() {
    return {
      cbId: "",
      focused: false
    };
  },
  computed: {
    ...mapGetters("config", [
      "vars"
    ]),
    listeners() {
      return {
        ...this.$listeners,
        input: this.updateValue,
        focus: this.onFocus,
        blur: this.onBlur
      };
    },
    slotData() {
      return {
        focused: this.focused,
        ...this.listeners
      };
    },
    hasIcon() {
      const { addonRight, addonLeft } = this.$slots;
      return addonRight !== void 0 || addonLeft !== void 0 || this.addonRightIcon !== void 0 || this.addonLeftIcon !== void 0 || this.addonRightText !== void 0 || this.addonLeftText !== void 0 || this.computedCurrency;
    },
    sizeClass() {
      return this.size ? "input-" + this.size : "";
    },
    computedCurrency() {
      if (this.format !== "currency") {
        return null;
      }
      return this.currency ? this.currency : this.vars.defaultCurrency;
    },
    computedStep() {
      return this.$attrs.step ? this.$attrs.step : this.computedCurrency && this.computedCurrency.decimal ? 1 / Math.pow(10, this.computedCurrency.decimal) : 0.01;
    }
  },
  watch: {
    value: {
      deep: true,
      handler(newValue, oldValue) {
        if (this.isWrapper) {
          this.updateError(newValue);
        }
      }
    }
  },
  methods: {
    formatInput(value) {
      switch (this.format) {
        case "uppercase":
          value = value.toUpperCase();
          break;
        case "lowercase":
          value = value.toLowerCase();
          break;
        case "capitalize":
          value = value.capitalize();
          break;
        case "sentence":
          value = value.toSentenceCase();
          break;
        case "startCase":
          value = value.startCase();
          break;
        case "camelCase":
          value = value.camelCase();
          break;
        case "snakeCase":
          value = value.snakeCase();
          break;
        case "kebabCase":
          value = value.kebabCase();
          break;
        case "trimSpace":
          value = value.trim();
          break;
        case "removeSpace":
          value = value.replace(" ", "");
          break;
        case "currency":
          value = formatCurrency.to(value, this.computedCurrency, false, false, true, false);
          break;
      }
      this.$emit("input", value);
    },
    formatInputDebounced: _.debounce(function(value) {
      this.formatInput(value);
    }, 300),
    updateValue(event) {
      let value = event.target.value;
      this.updateError(value);
      this.$emit("input", value);
      if (this.value && this.format && this.formatOn === "input") {
        this.formatInputDebounced(value);
      }
    },
    onFocus(event) {
      this.focused = true;
      if (this.value && this.format && this.formatOn === "focus") {
        this.formatInput(event.target.value);
      }
      this.$emit("focus", event);
    },
    onBlur(event) {
      this.focused = false;
      if (this.value && this.format && this.formatOn === "blur") {
        this.formatInput(event.target.value);
      }
      this.updateError(this.value);
      this.$emit("blur", event);
    },
    focus() {
      setTimeout(() => {
        this.$refs[`base-input-${this.$attrs.name ? this.$attrs.name : this.cbId}`].focus();
      }, 300);
    },
    updateError(val, error = "") {
      if (val) {
        this.$emit("update:error", error);
      }
    }
  },
  mounted() {
    if (this.autoFocus) {
      this.$refs[`base-input-${this.$attrs.name ? this.$attrs.name : this.cbId}`].focus();
    }
  },
  created() {
    this.cbId = Math.random().toString(16).slice(2);
  }
};
var _sfc_render = function render() {
  var _vm = this, _c = _vm._self._c;
  return _c("div", { staticClass: "base-input" }, [_c("div", { staticClass: "form-group", class: [
    { "input-group": _vm.hasIcon },
    _vm.sizeClass,
    { "focused": _vm.focused },
    { "input-group-alternative": _vm.alternative && !_vm.native },
    { "input-group-material": !(_vm.native || _vm.alternative) },
    { "is-naked": _vm.naked },
    { "has-label": _vm.label || _vm.$slots.label },
    { "has-success": _vm.valid === true },
    { "has-danger": _vm.error || _vm.valid === false },
    { "not-empty": _vm.value || _vm.value === 0 },
    { "required": _vm.required },
    _vm.wrapperClasses
  ] }, [(_vm.computedCurrency || _vm.addonLeftText || _vm.addonLeftIcon || _vm.$slots.addonLeft) && !_vm.hidePrefixSuffix ? _c("div", { staticClass: "input-group-prepend" }, [_c("span", { staticClass: "input-group-text" }, [_vm._t("addonLeft", function() {
    return [_vm.computedCurrency && !_vm.hidePrefixSuffix ? _c("span", [_vm._v(_vm._s(_vm.computedCurrency.prefix))]) : _vm.addonLeftText ? _c("span", [_vm._v(_vm._s(_vm.addonLeftText))]) : _c("i", { class: _vm.addonLeftIcon })];
  })], 2)]) : _vm._e(), _vm._t("label", function() {
    return [_vm.label || _vm.label === " " ? _c("label", { class: _vm.labelClasses, attrs: { "for": `base-input-${_vm.$attrs.name ? _vm.$attrs.name : _vm.cbId}` } }, [_vm._v(" " + _vm._s(_vm.label) + " "), _vm.required ? _c("span", { staticClass: "required-asterix" }, [_vm._v("*")]) : _vm._e()]) : _vm._e()];
  }), _vm._t("default", function() {
    return [_vm.$attrs.type === "number" ? [_c("input", _vm._g(_vm._b({ directives: [{ name: "auto-focus", rawName: "v-auto-focus", value: _vm.autoFocus, expression: "autoFocus" }, { name: "select-on-focus", rawName: "v-select-on-focus", value: _vm.selectOnFocus, expression: "selectOnFocus" }, { name: "translate-on-blur", rawName: "v-translate-on-blur", value: _vm.translateOnBlur, expression: "translateOnBlur" }], ref: `base-input-${_vm.$attrs.name ? _vm.$attrs.name : _vm.cbId}`, class: ["form-control", { "is-valid": !_vm.error && _vm.valid === true }, { "is-invalid": _vm.error || _vm.valid === false }, _vm.inputClasses], attrs: { "id": `base-input-${_vm.$attrs.name ? _vm.$attrs.name : _vm.cbId}`, "autofocus": _vm.autoFocus, "aria-describedby": "addon-right addon-left", "min": _vm.$attrs.min ? _vm.$attrs.min : _vm.format === "currency" ? 0 : null, "step": _vm.computedStep }, domProps: { "value": _vm.value } }, "input", _vm.$attrs, false), _vm.listeners))] : [_c("input", _vm._g(_vm._b({ directives: [{ name: "auto-focus", rawName: "v-auto-focus", value: _vm.autoFocus, expression: "autoFocus" }, { name: "select-on-focus", rawName: "v-select-on-focus", value: _vm.selectOnFocus, expression: "selectOnFocus" }, { name: "translate-on-blur", rawName: "v-translate-on-blur", value: _vm.translateOnBlur, expression: "translateOnBlur" }], ref: `base-input-${_vm.$attrs.name ? _vm.$attrs.name : _vm.cbId}`, class: ["form-control", { "is-valid": !_vm.error && _vm.valid === true }, { "is-invalid": _vm.error || _vm.valid === false }, _vm.inputClasses], attrs: { "id": `base-input-${_vm.$attrs.name ? _vm.$attrs.name : _vm.cbId}`, "autofocus": _vm.autoFocus, "aria-describedby": "addon-right addon-left" }, domProps: { "value": _vm.value } }, "input", _vm.$attrs, false), _vm.listeners))]];
  }, null, _vm.slotData), (_vm.computedCurrency || _vm.addonRightText || _vm.addonRightIcon || _vm.$slots.addonRight) && !_vm.hidePrefixSuffix ? _c("div", { staticClass: "input-group-append" }, [_c("span", { staticClass: "input-group-text" }, [_vm._t("addonRight", function() {
    return [_vm.addonRightIcon === "far fa-calendar-alt" && _vm.value && _vm.allowEmpty ? _c("a", { directives: [{ name: "b-tooltip", rawName: "v-b-tooltip.hover", modifiers: { "hover": true } }], staticClass: "clear-date", attrs: { "title": _vm.$t("general.clear") }, on: { "click": function($event) {
      $event.preventDefault();
      return _vm.$emit("input", "");
    } } }, [_c("i", { staticClass: "fas fa-times" })]) : _vm._e(), _vm.computedCurrency && !_vm.hidePrefixSuffix ? _c("span", [_vm._v(_vm._s(_vm.computedCurrency.suffix))]) : _vm.addonRightText ? _c("span", [_vm._v(_vm._s(_vm.addonRightText))]) : _c("i", { class: _vm.addonRightIcon })];
  })], 2)]) : _vm._e()], 2), _vm._t("infoBlock"), _vm._t("errorBlock", function() {
    return [_vm.error ? _c("div", { staticClass: "text-danger invalid-feedback error-block" }, [_vm._v(" " + _vm._s(_vm.error) + " ")]) : _vm._e()];
  })], 2);
};
var _sfc_staticRenderFns = [];
var __component__ = /* @__PURE__ */ normalizeComponent(
  _sfc_main,
  _sfc_render,
  _sfc_staticRenderFns,
  false,
  null,
  "bb5ed607",
  null,
  null
);
const BaseInput = __component__.exports;
export {
  BaseInput as default
};
//# sourceMappingURL=BaseInput.3f7306e6.js.map
