import { f as form } from "./form.ff4ac955.js";
import { E as EditorWrapper } from "./EditorWrapper.6dc46fdc.js";
import { I as ImageUploader } from "./ImageUploader.fa5c4dda.js";
import { E as EventBus } from "./event-bus.0afcd682.js";
import { K as KProgress } from "./vendor/vendor-k-progress.1391d9d5.js";
import { n as normalizeComponent } from "./_plugin-vue2_normalizer.7b9a2fe2.js";
const _sfc_main = {
  extends: form,
  components: {
    EditorWrapper,
    ImageUploader,
    KProgress
  },
  data() {
    return {
      formData: {
        uuid: null,
        title: "",
        body: "",
        slug: "",
        status: false,
        template: null,
        parent: null,
        media: null,
        meta: {
          seoTitle: "",
          keywords: "",
          description: "",
          showFooter: false
        }
      },
      preRequisite: {
        templates: [],
        parents: []
      },
      initUrl: "utility/notes",
      seoRecommendedMinChars: 180,
      seoRecommendedMaxChars: 220,
      progressBarColors: [
        "#f5365c",
        "#fb6340",
        "#ffd600",
        "#5e72e4",
        "#2dce89"
      ]
    };
  },
  computed: {
    imageUploadURL() {
      return `notes/${this.formData.uuid}/media`;
    },
    seoTitleProgressStatus() {
      let val = this.getProgress(this.formData.meta.seoTitle, 50);
      return val < 50 ? "error" : val < 99 ? "success" : "warning";
    },
    seoDescProgressStatus() {
      let val = this.getProgress(this.formData.meta.description, 145, 5);
      return val < 50 ? "error" : val < 99 ? "success" : "warning";
    },
    formStatus() {
      if (!this.formData.uuid) {
        return "creating";
      } else if (this.editData && !this.duplicate) {
        return "editing";
      } else {
        return "saved";
      }
    },
    seoTitle: {
      get() {
        return this.formData.meta.seoTitle || this.formData.title;
      },
      set(v) {
        this.formData.meta.seoTitle = v;
      }
    },
    seoDescription: {
      get() {
        return this.formData.meta.description ? this.formData.meta.description : this.getExcerpt(this.formData.body);
      },
      set(v) {
        this.formData.meta.description = v;
      }
    },
    seoUrl() {
      return this.getLocation() + "/.../" + this.formData.slug;
    }
  },
  methods: {
    getProgress(str, total, diff = 1) {
      let val = parseInt((str.length / (total + diff) * 100).toFixed(0));
      return val > 100 ? 100 : val;
    },
    publish() {
      this.formData.status = true;
      this.submit();
    },
    draft() {
      this.formData.status = false;
      this.submit();
    },
    createSlug() {
      if (this.showKeepAdding && this.formData.title != this.initialFormData.title) {
        this.formData.slug = this.formData.title.kebabCase();
      } else {
        this.formData.slug = this.formData.slug ? this.formData.slug : this.formData.title.kebabCase();
      }
    },
    getLocation() {
      return document.location.origin;
    },
    uploadedImage() {
      if (this.formStatus === "editing") {
        this.getEntityData();
      } else {
        this.$router.back();
      }
    },
    uploadedImageError() {
      if (this.formStatus === "saved") {
        this.$router.back();
      } else {
        EventBus.$emit("CANCEL_UPLOAD");
      }
    },
    noNeedCallback() {
      if (this.formStatus === "saved") {
        this.$router.back();
      } else {
        this.getEntityData();
      }
    },
    afterEditData() {
      if (this.duplicate) {
        this.formData.uuid = null;
        this.formData.status = false;
        this.formData.media = null;
      }
    },
    afterSubmit(response) {
      if (!this.formData.uuid) {
        this.formData.uuid = response.page.uuid;
      }
      this.initialFormData = _.cloneDeep(this.formData);
      if (this.formData.uuid) {
        this.$nextTick(() => {
          EventBus.$emit("START_UPLOAD");
        });
      }
    },
    getExcerpt(str) {
      return formUtil.getExcerpt(formUtil.stripHtml(str), 300);
    }
  },
  mounted() {
    this.getInitialData();
  }
};
var _sfc_render = function render() {
  var _vm = this, _c = _vm._self._c;
  return _c("form", { on: { "submit": function($event) {
    $event.preventDefault();
    return _vm.doNothing.apply(null, arguments);
  } } }, [_c("animated-loader", { attrs: { "is-loading": _vm.isLoading || _vm.isFetching, "loader-color": _vm.vars.loaderColor } }), _c("div", { staticClass: "row" }, [_c("div", { staticClass: "col-12 col-md-9" }, [_c("base-container", { attrs: { "boxed": "" } }, [_c("div", { staticClass: "row" }, [_c("div", { staticClass: "col-12 mb-3" }, [_c("base-input", { attrs: { "auto-focus": "", "label": _vm.$t("utility.note.props.title"), "type": "text", "error": _vm.formErrors.title, "required": "" }, on: { "update:error": function($event) {
    return _vm.$set(_vm.formErrors, "title", $event);
  }, "blur": _vm.createSlug }, model: { value: _vm.formData.title, callback: function($$v) {
    _vm.$set(_vm.formData, "title", $$v);
  }, expression: "formData.title" } })], 1), _c("div", { staticClass: "col-12 mt-4 mb-3" }, [_c("editor-wrapper", { attrs: { "label": _vm.$t("utility.note.props.body"), "error": _vm.formErrors.body, "required": "" }, on: { "update:error": function($event) {
    return _vm.$set(_vm.formErrors, "body", $event);
  } }, model: { value: _vm.formData.body, callback: function($$v) {
    _vm.$set(_vm.formData, "body", $$v);
  }, expression: "formData.body" } })], 1), _c("div", { staticClass: "col-12 mb-3" }, [_c("base-input", { attrs: { "label": _vm.$t("utility.note.props.slug"), "type": "text", "error": _vm.formErrors.slug, "format": "kebabCase", "required": "" }, on: { "update:error": function($event) {
    return _vm.$set(_vm.formErrors, "slug", $event);
  }, "blur": _vm.createSlug, "focus": _vm.createSlug }, model: { value: _vm.formData.slug, callback: function($$v) {
    _vm.$set(_vm.formData, "slug", $$v);
  }, expression: "formData.slug" } }), _vm.formData.slug ? _c("div", { staticClass: "small text-muted" }, [_vm._v(_vm._s(_vm.getLocation() + "/.../" + _vm.formData.slug))]) : _vm._e()], 1)]), _c("fieldset", { staticClass: "fieldset primary mt-5" }, [_c("legend", [_vm._v(_vm._s(_vm.$t("site.seo")))]), _vm.seoTitle ? _c("div", { staticClass: "search-preview-wrapper mb-4" }, [_c("h6", { staticClass: "text-muted mb-3" }, [_vm._v(_vm._s(_vm.$t("site.google_preview")))]), _c("div", { staticClass: "title" }, [_vm._v(_vm._s(_vm._f("charLimit")(_vm.seoTitle, 50)))]), _c("div", { staticClass: "url" }, [_vm._v(_vm._s(_vm._f("charLimit")(_vm.seoUrl, 70)))]), _c("div", { staticClass: "description" }, [_vm._v(_vm._s(_vm._f("charLimit")(_vm.seoDescription, 145)))])]) : _vm._e(), _c("div", { staticClass: "row" }, [_c("div", { staticClass: "col-12 mb-3" }, [_c("base-input", { attrs: { "label": _vm.$t("utility.note.props.seo_title"), "type": "text", "error": _vm.formErrors.seoTitle }, on: { "update:error": function($event) {
    return _vm.$set(_vm.formErrors, "seoTitle", $event);
  } }, model: { value: _vm.formData.meta.seoTitle, callback: function($$v) {
    _vm.$set(_vm.formData.meta, "seoTitle", $$v);
  }, expression: "formData.meta.seoTitle" } }), _vm.formData.meta.seoTitle ? _c("k-progress", { attrs: { "show-text": false, "percent": _vm.getProgress(_vm.formData.meta.seoTitle, 50), "status": _vm.seoTitleProgressStatus } }) : _vm._e()], 1), _c("div", { staticClass: "col-12 mb-3" }, [_c("base-textarea", { attrs: { "rows": "2", "label": _vm.$t("utility.note.props.description"), "error": _vm.formErrors.description, "char-count": "" }, on: { "update:error": function($event) {
    return _vm.$set(_vm.formErrors, "description", $event);
  } }, model: { value: _vm.formData.meta.description, callback: function($$v) {
    _vm.$set(_vm.formData.meta, "description", $$v);
  }, expression: "formData.meta.description" } }), _vm.formData.meta.description ? _c("k-progress", { attrs: { "show-text": false, "percent": _vm.getProgress(_vm.formData.meta.description, 145, 5), "status": _vm.seoDescProgressStatus } }) : _vm._e()], 1), _c("div", { staticClass: "col-12" }, [_c("base-textarea", { attrs: { "rows": "2", "label": _vm.$t("utility.note.props.keywords"), "error": _vm.formErrors.keywords }, on: { "update:error": function($event) {
    return _vm.$set(_vm.formErrors, "keywords", $event);
  } }, model: { value: _vm.formData.meta.keywords, callback: function($$v) {
    _vm.$set(_vm.formData.meta, "keywords", $$v);
  }, expression: "formData.meta.keywords" } })], 1)])])])], 1), _c("div", { staticClass: "col-12 col-md-3 d-flex flex-column" }, [_c("card", { staticClass: "mb-4" }, [_c("div", { staticClass: "row" }, [_c("div", { staticClass: "col-12" }, [_c("view-single", { attrs: { "data-classes": "small", "label": _vm.$t("utility.note.note") + " " + _vm.$t("utility.note.props.status"), "value": _vm.formData.status ? _vm.$t("site.published") : _vm.$t("site.draft") } })], 1), _vm.editData && !_vm.duplicate ? [_c("div", { staticClass: "col-12" }, [_c("view-date", { attrs: { "data-classes": "small", "label": _vm.$t("general.created_at"), "value": _vm.formData.createdAt, "to-format": _vm.vars.defaultDateTimeFormat } })], 1), _c("div", { staticClass: "col-12" }, [_c("view-date", { attrs: { "data-classes": "small", "label": _vm.$t("general.updated_at"), "value": _vm.formData.updatedAt, "to-format": _vm.vars.defaultDateTimeFormat } })], 1)] : _vm._e()], 2), _vm.formHasErrors ? _c("div", { staticClass: "alert alert-danger my-3", attrs: { "role": "alert" } }, [_c("h6", { staticClass: "m-0" }, [_vm._v(_vm._s(_vm.$t("general.form_has_errors")))])]) : _vm._e(), _c("div", { staticClass: "form-footer mt-3" }, [_vm.formData.status ? _c("div", { key: "published", staticClass: "both-side" }, [_c("base-button", { staticClass: "text-center", attrs: { "type": "button", "design": "link", "tabindex": "-1" }, on: { "click": _vm.draft } }, [_vm._v(_vm._s(_vm.$t("site.unpublish")))]), _c("base-button", { attrs: { "type": "button", "design": "primary" }, on: { "click": _vm.publish } }, [_vm._v(_vm._s(_vm.$t("general.update")))])], 1) : _c("div", { key: "draft", staticClass: "both-side" }, [_c("base-button", { attrs: { "type": "button", "design": "light" }, on: { "click": _vm.draft } }, [_vm.formData.uuid ? [_vm._v(_vm._s(_vm.$t("general.update")))] : [_vm._v(_vm._s(_vm.$t("general.save")))]], 2), _c("base-button", { attrs: { "type": "button", "design": "primary" }, on: { "click": _vm.publish } }, [_vm._v(_vm._s(_vm.$t("general.publish")))])], 1)])]), _c("card", { staticClass: "mb-4", attrs: { "title": _vm.$t("site.featured_image") } }, [_c("div", { staticClass: "row" }, [_c("div", { staticClass: "col-12 d-flex justify-content-center" }, [_c("image-uploader", { attrs: { "url": _vm.imageUploadURL, "existing-image": _vm.formData.media ? _vm.formData.media.url : null, "existing-media": _vm.formData.media, "show-upload-button": !_vm.showKeepAdding }, on: { "uploaded": _vm.uploadedImage, "error": _vm.uploadedImageError, "noNeed": _vm.noNeedCallback, "removed": _vm.getEntityData } })], 1)])]), _c("card", { staticClass: "mb-4", attrs: { "title": _vm.$t("site.attributes") } }, [_c("div", { staticClass: "row" }, [_c("div", { staticClass: "col-12 mb-3" }, [_c("base-select", { attrs: { "options": _vm.preRequisite.templates, "label": _vm.$t("site.page_template.template"), "error": _vm.formErrors.template, "required": "", "preselect-first": "" }, on: { "update:error": function($event) {
    return _vm.$set(_vm.formErrors, "template", $event);
  } }, model: { value: _vm.formData.template, callback: function($$v) {
    _vm.$set(_vm.formData, "template", $$v);
  }, expression: "formData.template" } })], 1), _c("div", { staticClass: "col-12 mb-3" }, [_c("base-select", { attrs: { "options": _vm.preRequisite.pages, "label": _vm.$t("utility.note.props.parent"), "error": _vm.formErrors.parent, "allow-empty": true }, on: { "update:error": function($event) {
    return _vm.$set(_vm.formErrors, "parent", $event);
  } }, model: { value: _vm.formData.parent, callback: function($$v) {
    _vm.$set(_vm.formData, "parent", $$v);
  }, expression: "formData.parent" } })], 1)])]), _c("card", { staticClass: "flex-grow", attrs: { "title": _vm.$t("site.options") } }, [_c("div", { staticClass: "row" })])], 1)])], 1);
};
var _sfc_staticRenderFns = [];
var __component__ = /* @__PURE__ */ normalizeComponent(
  _sfc_main,
  _sfc_render,
  _sfc_staticRenderFns,
  false,
  null,
  null,
  null,
  null
);
const CommonForm = __component__.exports;
export {
  CommonForm as C
};
//# sourceMappingURL=form.199b19bc.js.map
