import { b as swtAlert, d as copyToClipboard } from "./app.9a8150b2.js";
import { d as browser } from "./vendor/vendor-essential.31dae676.js";
function hasGetUserMedia() {
  return !!(navigator.mediaDevices && navigator.mediaDevices.getUserMedia);
}
if (!hasGetUserMedia()) {
  alert($t("misc.get_user_media_not_supported"));
}
if (navigator.mediaDevices && navigator.mediaDevices.enumerateDevices) {
  navigator.enumerateDevices = function(callback) {
    navigator.mediaDevices.enumerateDevices().then(callback);
  };
}
if (typeof MediaStreamTrack !== "undefined" && "getSources" in MediaStreamTrack)
  ;
else if (navigator.mediaDevices && !!navigator.mediaDevices.enumerateDevices)
  ;
const playAudio = function(opts) {
  const defaultOpts = {
    type: null,
    loop: false,
    duration: 1e3
  };
  opts = Object.assign({}, defaultOpts, opts);
  if (!opts.type) {
    return;
  }
  const audioEle = new Audio();
  audioEle.preload = "auto";
  audioEle.autoplay = true;
  audioEle.loop = opts.loop;
  audioEle.src = `/sound/${opts.type}.mp3`;
  audioEle.play().then(() => {
    setTimeout(() => {
      audioEle && audioEle.pause();
    }, opts.duration);
  }).catch((error) => {
    console.error(error);
  });
  return audioEle;
};
const playIncomingCall = function(onCondition = true) {
  if (document.hasFocus() && !onCondition) {
    return;
  }
  return playAudio({ type: "incoming", loop: true, duration: 3e4 });
};
const playOutgoingCall = function(onCondition = true) {
  if (document.hasFocus() && !onCondition) {
    return;
  }
  return playAudio({ type: "calling", loop: true, duration: 3e4 });
};
const playIncomingMessage = function(onCondition = true) {
  if (document.hasFocus() && !onCondition) {
    return;
  }
  return playAudio({ type: "message", duration: 3e3 });
};
const playScreenshot = function(onCondition = true) {
  if (document.hasFocus() && !onCondition) {
    return;
  }
  return playAudio({ type: "screenshot", duration: 3e3 });
};
const share = async function(data = {}, callback, useNativeShare = true) {
  const currentUrl = document.querySelector("link[rel=canonical]") ? document.querySelector("link[rel=canonical]").href : document.location.href;
  const url = data.url ? data.url : currentUrl;
  if (useNativeShare && navigator.share) {
    const shareOpts = {
      title: data.title ? data.title : document.title,
      text: data.text ? data.text : document.description,
      url
    };
    const blobToFile = (fileBlob, { name, type }) => {
      return new File([fileBlob], name, {
        type: fileBlob.type,
        lastModified: new Date().getTime()
      });
    };
    const blobFromPath = async (filePath) => {
      return await (await fetch(filePath)).blob();
    };
    const blobFromDataUrl = async (dataUrl) => {
      return await (await fetch(dataUrl)).blob();
    };
    if (data.file) {
      let files = [];
      const fileBlob = data.file.dataUrl ? await blobFromDataUrl(data.file.dataUrl) : await blobFromPath(data.file.path);
      const myFile = await blobToFile(fileBlob, data.file);
      files.push(myFile);
      if (files.length && navigator.canShare && navigator.canShare({ files })) {
        shareOpts.files = files;
      }
    }
    navigator.share(shareOpts).catch(console.error);
  } else {
    let alertContent = {
      showCancelButton: true,
      confirmButtonText: $t("misc.share_alert.confirm_btn"),
      cancelButtonText: $t("misc.share_alert.cancel_btn")
    };
    if (data.alertTitle) {
      alertContent.title = data.alertTitle;
    }
    if (data.alertHtml) {
      alertContent.html = data.alertHtml;
    } else {
      alertContent.text = $t("misc.share_alert.text");
    }
    swtAlert.fire(alertContent).then((result) => {
      if (result.value) {
        copyToClipboard(url);
        setTimeout(() => {
          callback();
        }, 500);
      }
    });
  }
};
const getQRCode = function(params = {}) {
  const defaultOpts = {
    data: null,
    icon: "",
    size: 350,
    iconSize: 60,
    success: null,
    error: null
  };
  const opts = Object.assign({}, defaultOpts, params);
  if (!opts.data || !opts.success) {
    throw "Insufficient parameters!";
  }
  const canvasElement = document.createElement("canvas");
  canvasElement.width = opts.size;
  canvasElement.height = opts.size;
  const ctx = canvasElement.getContext("2d");
  ctx.clearRect(0, 0, canvasElement.width, canvasElement.height);
  let img = new Image();
  const putIconOnQR = (selectedImg) => {
    const iconStartPosition = (opts.size - opts.iconSize) / 2;
    ctx.beginPath();
    ctx.rect(iconStartPosition - 4, iconStartPosition - 4, opts.iconSize + 8, opts.iconSize + 8);
    ctx.fillStyle = "#FFFFFF";
    ctx.fill();
    ctx.drawImage(selectedImg, iconStartPosition, iconStartPosition, opts.iconSize, opts.iconSize);
  };
  const canvasImageElement = document.createElement("canvas");
  canvasImageElement.width = opts.iconSize;
  canvasImageElement.height = opts.iconSize;
  const ctxImage = canvasImageElement.getContext("2d");
  ctxImage.clearRect(0, 0, canvasImageElement.width, canvasImageElement.height);
  browser.toCanvas(canvasElement, opts.data, {
    errorCorrectionLevel: "H",
    margin: 2,
    width: opts.size
  }, (error) => {
    if (error) {
      if (opts.error && _.isFunction(opts.error)) {
        opts.error(error);
        return;
      }
      console.error(error);
      throw error;
    }
    if (opts.icon) {
      img.onload = () => {
        putIconOnQR(img);
        if (opts.success && _.isFunction(opts.success)) {
          opts.success(canvasElement.toDataURL("image/png"));
        }
      };
      img.src = opts.icon;
    } else {
      if (opts.success && _.isFunction(opts.success)) {
        opts.success(canvasElement.toDataURL("image/png"));
      }
    }
  });
};
export {
  playIncomingCall as a,
  playOutgoingCall as b,
  playScreenshot as c,
  getQRCode as g,
  playIncomingMessage as p,
  share as s
};
//# sourceMappingURL=media.10b7361f.js.map
