import { m as mapGetters, d as axios } from "./vendor/vendor-core.2a9962eb.js";
import { u as uploadFile, r as removeFile } from "./uploader.39656730.js";
import { E as EventBus } from "./event-bus.0afcd682.js";
import { e as fileIcons, h as fileMimeTypes } from "./app.9a8150b2.js";
import { n as normalizeComponent } from "./_plugin-vue2_normalizer.7b9a2fe2.js";
import { b as v4 } from "./vendor/vendor-essential.31dae676.js";
const _sfc_main = {
  name: "file-uploader",
  components: {},
  props: {
    data: {
      type: Array,
      default() {
        return [];
      }
    },
    additionalFormData: {
      type: Object,
      default() {
        return {};
      }
    },
    requestIdentifier: {
      type: String,
      default: v4()
    },
    url: {
      type: String,
      default: "/uploads"
    },
    heading: {
      type: String,
      default: null
    },
    actionLabel: {
      type: String,
      default: "global.choose"
    },
    nameLabel: {
      type: String,
      default: "upload.file"
    },
    namesLabel: {
      type: String,
      default: "upload.files"
    },
    buttonWrapperClasses: {
      type: String,
      default: "justify-content-start"
    },
    headingClasses: {
      type: String,
      default: "mb-2"
    },
    buttonClasses: {
      type: String,
      default: "mb-2"
    },
    buttonIcon: {
      type: String,
      default: "fas fa-upload"
    },
    buttonDesign: {
      type: String,
      default: "primary"
    },
    options: {
      type: Object,
      required: true
    },
    autoUpload: {
      type: Boolean,
      default: true
    },
    multiple: {
      type: Boolean,
      default: true
    },
    hideButtonLabel: {
      type: Boolean,
      default: false
    },
    hideFileList: {
      type: Boolean,
      default: false
    },
    hideResetButton: {
      type: Boolean,
      default: false
    },
    hideAfterUpload: {
      type: Boolean,
      default: true
    },
    showSelectedFilesCount: {
      type: Boolean,
      default: false
    }
  },
  data() {
    return {
      isLoading: false,
      fileRemoved: false,
      actionLabelUpdated: "",
      files: [],
      uploadedFiles: [],
      existingFiles: [],
      icons: fileIcons,
      mimeTypes: fileMimeTypes
    };
  },
  computed: {
    ...mapGetters("config", [
      "configs",
      "vars"
    ]),
    computedActionLabel() {
      return this.existingFile ? "global.change" : this.actionLabel;
    }
  },
  watch: {
    data(v) {
      this.existingFiles = v.map((f) => {
        return { ...f, status: null };
      });
    },
    "options.uuid": {
      deep: true,
      handler(val, oldVal) {
        if (val && val !== oldVal) {
          this.reset();
        }
      }
    }
  },
  methods: {
    getFileIcon(type) {
      return this.icons[type] || "fa-file-alt";
    },
    getFileNameIcon(type) {
      return this.icons[type] || "fa-file-alt";
    },
    generateFilesList(e) {
      this.isLoading = true;
      let allowedExtensions = null;
      const selectedFiles = this.$refs.filesInput.files;
      if (this.options.allowedExtensions) {
        if (!_.isArray(this.options.allowedExtensions)) {
          this.options.allowedExtensions = this.options.allowedExtensions.split(",");
        }
        allowedExtensions = new RegExp("(." + this.options.allowedExtensions.join("|.") + ")$");
      }
      if (this.options.maxNoOfFiles && selectedFiles.length + this.existingFiles.length > this.options.maxNoOfFiles) {
        this.$toasted.error(this.$t("upload.max_file_limit_crossed", { number: this.options.maxNoOfFiles }), this.$toastConfig.error);
        return;
      }
      for (let i = 0; i < selectedFiles.length; i++) {
        if (allowedExtensions && !allowedExtensions.test(selectedFiles[i].name)) {
          this.isLoading = false;
          this.$toasted.error(this.$t("global.file_not_supported", { attribute: selectedFiles[i].name.split(".").pop() }), this.$toastConfig.error);
        } else if (selectedFiles[i].size > this.configs.system.postMaxSize) {
          this.isLoading = false;
          this.$toasted.error(this.$t("global.file_too_large", { attribute: selectedFiles[i].name }), this.$toastConfig.error);
        } else {
          this.files.push({
            uuid: v4(),
            file: selectedFiles[i],
            status: "waiting",
            progress: 0
          });
        }
      }
      this.isLoading = false;
      this.$emit("selected", this.files.length);
      if (this.autoUpload) {
        this.startUploading();
      }
    },
    startUploading() {
      const filesToUpload = this.files.filter((fileObj) => fileObj.status === "waiting");
      if (filesToUpload.length) {
        let onUploadProgressArr = [];
        const CancelToken = axios.CancelToken;
        this.$emit("uploading", this.files.length);
        for (let i = 0; i < this.files.length; i++) {
          const uploadObj = this.files[i];
          onUploadProgressArr[i] = (progressEvent) => {
            uploadObj.progress = Math.round(progressEvent.loaded * 100 / progressEvent.total);
          };
          if (uploadObj.status === "waiting") {
            let formData = new FormData();
            formData.append("file", uploadObj.file);
            formData.append("mime", uploadObj.file.type);
            formData.append("token", this.options.token);
            formData.append("module", this.options.module);
            formData.append("request_uuid", this.requestIdentifier);
            formData.append("first_attachment", i === 0);
            formData.append("last_attachment", i === this.files.length - 1);
            this.additionalFormData.objForEach((value, key) => {
              if (value) {
                if (_.isObject(value)) {
                  formData.append(key.snakeCase(), JSON.stringify(value));
                } else {
                  formData.append(key.snakeCase(), value);
                }
              }
            });
            uploadObj.status = "uploading";
            let cancelToken = new CancelToken((c) => {
              uploadObj.cancel = c;
            });
            uploadFile({
              url: this.url,
              data: formData
            }, onUploadProgressArr[i], cancelToken).then((response) => {
              if (response.upload) {
                this.uploadedFiles.push(response.upload);
              } else if (response.attachments) {
                this.uploadedFiles.push(response.attachments);
              }
              uploadObj.uuid = response.upload ? response.upload.uuid : response.uuid;
              uploadObj.status = "justUploaded";
              delete uploadObj.cancel;
              setTimeout(() => {
                uploadObj.status = "uploaded";
                if (this.hideAfterUpload) {
                  delete this.files.splice(this.files.findIndex((f) => f.uuid === uploadObj.uuid), 1);
                }
              }, 2e3);
              this.$emit("updated", response);
              this.checkUploadStatus(response);
            }).catch((thrown) => {
              this.$emit("error", {
                ...thrown,
                requestUuid: this.requestIdentifier
              });
              if (thrown.response && thrown.response.data) {
                const data = thrown.response.data || {};
                const errors = data.errors ? formUtil.assignErrors(data.errors) : {};
                uploadObj.error = errors.message;
                this.$toasted.error(errors.message, this.$toastConfig.error);
                uploadObj.status = "error";
                setTimeout(() => {
                  delete this.files.splice(this.files.findIndex((f) => f.uuid === uploadObj.uuid), 1);
                }, 3e3);
                this.$emit("updated", {
                  ...thrown,
                  requestUuid: this.requestIdentifier
                });
                this.checkUploadStatus();
              } else {
                uploadObj.status = "cancelled";
                setTimeout(() => {
                  delete this.files.splice(this.files.findIndex((f) => f.uuid === uploadObj.uuid), 1);
                }, 3e3);
              }
            });
          }
        }
      }
    },
    removeFile(fileObj, index, existing = false) {
      formUtil.confirmAction().then((result) => {
        if (result.value) {
          this.isLoading = true;
          removeFile({
            url: this.url + "/" + fileObj.uuid,
            data: {
              token: this.options.token,
              module: this.options.module
            }
          }).then((response) => {
            fileObj.status = "removed";
            setTimeout(() => {
              if (existing) {
                delete this.existingFiles.splice(this.existingFiles.findIndex((f) => f.uuid === fileObj.uuid), 1);
              } else {
                delete this.files.splice(this.files.findIndex((f) => f.uuid === fileObj.uuid), 1);
              }
            }, 3e3);
            this.isLoading = false;
            this.$toasted.success(response.message, this.$toastConfig.success);
            this.$emit("selected", this.files.length);
            this.$emit("updated", response);
            this.checkUploadStatus();
          }).catch((thrown) => {
            const data = thrown.response.data || {};
            const errors = data.errors ? formUtil.assignErrors(data.errors) : {};
            this.$toasted.error(errors.message, this.$toastConfig.error);
            fileObj.error = errors.message;
            fileObj.status = "removeError";
          });
        }
      });
    },
    checkUploadStatus(response) {
      let status = true;
      for (let i = 0; i < this.files.length; i++) {
        if (this.files[i].status !== "justUploaded" && this.files[i].status !== "uploaded") {
          status = false;
        }
      }
      if (status) {
        this.$emit("uploaded", this.uploadedFiles);
      } else {
        this.$emit("error", {
          requestUuid: this.requestIdentifier
        });
      }
    },
    reset() {
      this.isLoading = false;
      this.fileRemoved = false;
      this.actionLabelUpdated = "";
      this.files = [];
      this.uploadedFiles = [];
      const input = this.$refs.filesInput;
      input.type = "text";
      input.type = "file";
      this.$emit("selected", this.files.length);
    },
    startUpload() {
      if (this.files.length) {
        this.startUploading();
      } else {
        this.$emit("noNeed");
      }
    }
  },
  mounted() {
    EventBus.$off("START_UPLOAD", this.startUpload);
    EventBus.$on("START_UPLOAD", this.startUpload);
    EventBus.$off("RESET_UPLOAD", this.reset);
    EventBus.$on("RESET_UPLOAD", this.reset);
    this.existingFiles = this.data.map((f) => {
      return { ...f, status: null };
    });
  },
  filters: {
    decimal(value, num = 2) {
      return Number(value).toFixed(num);
    }
  },
  destroyed() {
    EventBus.$off("START_UPLOAD", this.startUpload);
    EventBus.$off("RESET_UPLOAD", this.reset);
  }
};
var _sfc_render = function render() {
  var _vm = this, _c = _vm._self._c;
  return _c("div", { staticClass: "sm-uploader file-uploader" }, [_c("div", { staticClass: "file-uploader-form" }, [_c("div", { class: ["file-selector d-flex flex-wrap", _vm.buttonWrapperClasses] }, [_vm.heading ? _c("h5", { class: ["title-desc", _vm.headingClasses] }, [_vm._v(" " + _vm._s(_vm.heading) + " ")]) : _vm._e(), _c("label", { class: ["btn", `btn-${_vm.buttonDesign}`, _vm.buttonClasses] }, [_c("input", { ref: "filesInput", staticClass: "selector-input", attrs: { "name": "filesInput", "type": "file", "id": "filesInput", "multiple": _vm.multiple }, on: { "change": _vm.generateFilesList } }), _c("span", { staticClass: "button-icon" }, [_c("i", { class: _vm.buttonIcon })]), _vm._v(" "), !_vm.hideButtonLabel ? _c("span", { staticClass: "button-label" }, [_vm._v(_vm._s(_vm.$t(_vm.computedActionLabel, { attribute: _vm.$t(_vm.namesLabel) })))]) : _vm._e(), _vm._v(" "), _vm.showSelectedFilesCount && _vm.files.length ? _c("span", { staticClass: "button-label bracketed" }, [_vm._v(_vm._s(_vm.files.length))]) : _vm._e()]), _vm.hideFileList && !_vm.hideResetButton && _vm.files.length ? _c("button", { class: ["btn", `btn-${_vm.buttonDesign}`, _vm.buttonClasses], attrs: { "type": "button" }, on: { "click": _vm.reset } }, [_vm._m(0)]) : _vm._e()])]), _vm.existingFiles.length || _vm.uploadedFiles.length || _vm.files.length ? _c("div", { class: ["files-list-wrapper", { "d-none": _vm.hideFileList }] }, [_c("ul", { staticClass: "files-list" }, [_vm._l(_vm.existingFiles, function(fileObj, index) {
    return _c("li", { key: fileObj.uuid, staticClass: "file-details-row" }, [_c("div", { staticClass: "file-icon" }, [_c("span", [_c("i", { class: ["far", _vm.getFileIcon(fileObj.mime)] })])]), _c("div", { staticClass: "file-details" }, [_c("h6", [_vm._v(_vm._s(fileObj.filename))]), fileObj.error ? _c("p", { staticClass: "text-danger" }, [_vm._v(" " + _vm._s(fileObj.error) + " ")]) : _c("p", [_c("span", [_c("span", { staticClass: "font-weight-700" }, [_vm._v(_vm._s(_vm.$t("upload.type")))]), _vm._v(": " + _vm._s(_vm.mimeTypes[fileObj.mime] || fileObj.mime || "Unknown"))]), _c("span", { staticClass: "ml-1" }, [_c("span", { staticClass: "font-weight-700" }, [_vm._v(_vm._s(_vm.$t("upload.size")))]), _vm._v(": " + _vm._s(_vm._f("decimal")(fileObj.size / 1024, 0)) + " KB")])])]), _c("div", { class: ["status-wrapper", { "actions-wrapper": !fileObj.status || fileObj.status === "removeError" }] }, [_c("transition", { staticClass: "transition-wrapper", attrs: { "appear": "", "tag": "div", "name": "actions", "mode": "out-in" } }, [fileObj.status === "removed" ? _c("div", { staticClass: "status-removed-wrapper" }, [_c("label", { staticClass: "status-text text-danger" }, [_vm._v("Removed!")]), _c("span", { staticClass: "status-icon text-danger" }, [_c("i", { staticClass: "fas fa-trash" })])]) : !fileObj.status || fileObj.status === "removeError" ? _c("div", { staticClass: "actions-buttons" }, [fileObj.status === "removeError" ? _c("label", { staticClass: "status-text text-danger" }, [_vm._v("Error!")]) : _vm._e(), fileObj.status === "removeError" ? _c("span", { staticClass: "status-icon text-danger" }, [_c("i", { staticClass: "fas fa-exclamation-triangle" })]) : _vm._e(), _c("a", { directives: [{ name: "b-tooltip", rawName: "v-b-tooltip.hover.left", modifiers: { "hover": true, "left": true } }], staticClass: "download-btn", attrs: { "href": fileObj.fullUrl, "target": "_blank", "title": _vm.$t("global.download", { attribute: _vm.$t(_vm.nameLabel) }) } }, [_c("i", { staticClass: "fas fa-download" })]), _c("button", { directives: [{ name: "b-tooltip", rawName: "v-b-tooltip.hover.left", modifiers: { "hover": true, "left": true } }], staticClass: "remove-btn", attrs: { "type": "button", "title": _vm.$t("global.remove", { attribute: _vm.$t(_vm.nameLabel) }) }, on: { "click": function($event) {
      return _vm.removeFile(fileObj, index, true);
    } } }, [_c("i", { staticClass: "fas fa-trash" })])]) : _vm._e()])], 1)]);
  }), _vm._l(_vm.uploadedFiles, function(fileObj, index) {
    return _c("li", { key: fileObj.uuid, staticClass: "file-details-row" }, [_c("div", { staticClass: "file-icon" }, [_c("span", [_c("i", { class: ["far", _vm.getFileIcon(fileObj.mime)] })])]), _c("div", { staticClass: "file-details" }, [_c("h6", [_vm._v(_vm._s(fileObj.filename))]), fileObj.error ? _c("p", { staticClass: "text-danger" }, [_vm._v(" " + _vm._s(fileObj.error) + " ")]) : _c("p", [_c("span", [_c("span", { staticClass: "font-weight-700" }, [_vm._v(_vm._s(_vm.$t("upload.type")))]), _vm._v(": " + _vm._s(_vm.mimeTypes[fileObj.mime] || fileObj.mime || "Unknown"))]), _c("span", { staticClass: "ml-1" }, [_c("span", { staticClass: "font-weight-700" }, [_vm._v(_vm._s(_vm.$t("upload.size")))]), _vm._v(": " + _vm._s(_vm._f("decimal")(fileObj.size / 1024, 0)) + " KB")])])]), _c("div", { class: ["status-wrapper", { "actions-wrapper": !fileObj.status || fileObj.status === "removeError" }] }, [_c("transition", { staticClass: "transition-wrapper", attrs: { "appear": "", "tag": "div", "name": "actions", "mode": "out-in" } }, [fileObj.status === "removed" ? _c("div", { staticClass: "status-removed-wrapper" }, [_c("label", { staticClass: "status-text text-danger" }, [_vm._v("Removed!")]), _c("span", { staticClass: "status-icon text-danger" }, [_c("i", { staticClass: "fas fa-trash" })])]) : !fileObj.status || fileObj.status === "removeError" ? _c("div", { staticClass: "actions-buttons" }, [fileObj.status === "removeError" ? _c("label", { staticClass: "status-text text-danger" }, [_vm._v("Error!")]) : _vm._e(), fileObj.status === "removeError" ? _c("span", { staticClass: "status-icon text-danger" }, [_c("i", { staticClass: "fas fa-exclamation-triangle" })]) : _vm._e(), _c("a", { directives: [{ name: "b-tooltip", rawName: "v-b-tooltip.hover.left", modifiers: { "hover": true, "left": true } }], staticClass: "download-btn", attrs: { "href": fileObj.fullUrl, "target": "_blank", "title": _vm.$t("global.download", { attribute: _vm.$t(_vm.nameLabel) }) } }, [_c("i", { staticClass: "fas fa-download" })]), _c("button", { directives: [{ name: "b-tooltip", rawName: "v-b-tooltip.hover.left", modifiers: { "hover": true, "left": true } }], staticClass: "remove-btn", attrs: { "type": "button", "title": _vm.$t("global.remove", { attribute: _vm.$t(_vm.nameLabel) }) }, on: { "click": function($event) {
      return _vm.removeFile(fileObj, index, true);
    } } }, [_c("i", { staticClass: "fas fa-trash" })])]) : _vm._e()])], 1)]);
  }), _vm._l(_vm.files, function(fileObj, index) {
    return _c("li", { key: index, staticClass: "file-details-row" }, [_c("div", { staticClass: "file-icon" }, [_c("span", [_c("i", { class: ["far", _vm.getFileIcon(fileObj.file.type)] })])]), _c("div", { staticClass: "file-details" }, [_c("h6", [_vm._v(_vm._s(fileObj.file.name))]), fileObj.error ? _c("p", { staticClass: "text-danger" }, [_vm._v(" " + _vm._s(fileObj.error) + " ")]) : _c("p", [_c("span", [_c("span", { staticClass: "font-weight-700" }, [_vm._v(_vm._s(_vm.$t("upload.type")))]), _vm._v(": " + _vm._s(_vm.mimeTypes[fileObj.file.type] || "Unknown"))]), _c("span", { staticClass: "ml-1" }, [_c("span", { staticClass: "font-weight-700" }, [_vm._v(_vm._s(_vm.$t("upload.size")))]), _vm._v(": " + _vm._s(_vm._f("decimal")(fileObj.file.size / 1024, 0)) + " KB")])])]), _c("div", { class: ["status-wrapper", { "actions-wrapper": fileObj.status === "uploaded" || fileObj.status === "removeError" }] }, [_c("transition", { staticClass: "transition-wrapper", attrs: { "appear": "", "tag": "div", "name": "actions", "mode": "out-in" } }, [fileObj.status === "uploading" ? _c("div", { staticClass: "status-uploading-wrapper" }, [_c("label", { staticClass: "status-action", on: { "click": fileObj.cancel } }, [_vm._v(_vm._s(_vm.$t("general.cancel")))]), _c("progress-ring", { attrs: { "value": fileObj.progress, "stroke-color": _vm.vars.loaderColor } })], 1) : fileObj.status === "justUploaded" ? _c("div", { staticClass: "status-uploaded-wrapper" }, [_c("label", { staticClass: "status-text text-success" }, [_vm._v("Uploaded!")]), _c("span", { staticClass: "status-icon text-success" }, [_c("i", { staticClass: "fas fa-check" })])]) : fileObj.status === "cancelled" ? _c("div", { staticClass: "status-cancelled-wrapper" }, [_c("label", { staticClass: "status-text text-danger" }, [_vm._v("Cancelled!")]), _c("span", { staticClass: "status-icon text-danger" }, [_c("i", { staticClass: "fas fa-times" })])]) : fileObj.status === "removed" ? _c("div", { staticClass: "status-removed-wrapper" }, [_c("label", { staticClass: "status-text text-danger" }, [_vm._v("Removed!")]), _c("span", { staticClass: "status-icon text-danger" }, [_c("i", { staticClass: "fas fa-trash" })])]) : fileObj.status === "error" ? _c("div", { staticClass: "status-error-wrapper" }, [_c("label", { staticClass: "status-text text-danger" }, [_vm._v("Error!")]), _c("span", { staticClass: "status-icon text-danger" }, [_c("i", { staticClass: "fas fa-exclamation-triangle" })])]) : fileObj.status === "uploaded" || fileObj.status === "removeError" ? _c("div", { staticClass: "actions-buttons" }, [fileObj.status === "removeError" ? _c("label", { staticClass: "status-text text-danger" }, [_vm._v("Error!")]) : _vm._e(), fileObj.status === "removeError" ? _c("span", { staticClass: "status-icon text-danger" }, [_c("i", { staticClass: "fas fa-exclamation-triangle" })]) : fileObj.status === "uploaded" ? _c("label", { staticClass: "status-text text-success" }, [_vm._v("Uploaded!")]) : _vm._e(), _c("button", { directives: [{ name: "b-tooltip", rawName: "v-b-tooltip.hover.left", modifiers: { "hover": true, "left": true } }], staticClass: "remove-btn", attrs: { "type": "button", "title": _vm.$t("global.remove", { attribute: _vm.$t(_vm.nameLabel) }) }, on: { "click": function($event) {
      return _vm.removeFile(fileObj, index);
    } } }, [_c("i", { staticClass: "fas fa-trash" })])]) : _vm._e()])], 1)]);
  })], 2)]) : _vm._e()]);
};
var _sfc_staticRenderFns = [function() {
  var _vm = this, _c = _vm._self._c;
  return _c("span", { staticClass: "button-icon" }, [_c("i", { staticClass: "fas fa-times" })]);
}];
var __component__ = /* @__PURE__ */ normalizeComponent(
  _sfc_main,
  _sfc_render,
  _sfc_staticRenderFns,
  false,
  null,
  null,
  null,
  null
);
const FileUploader = __component__.exports;
export {
  FileUploader as F
};
//# sourceMappingURL=FileUploader.a3ada0d1.js.map
