import { m as mapGetters, i as mapActions } from "../vendor/vendor-core.2a9962eb.js";
import { b as playOutgoingCall } from "../media.10b7361f.js";
import { c as callAlert, S as Swal } from "../app.9a8150b2.js";
import { E as EventBus } from "../event-bus.0afcd682.js";
import { n as normalizeComponent } from "../_plugin-vue2_normalizer.7b9a2fe2.js";
import "../vendor/vendor-essential.31dae676.js";
import "../vendor/vendor-others.d4f8aae2.js";
import "../vendor/vendor-bootstrap-vue.397f83c5.js";
import "../vendor/vendor-vue-gtag.137cb49d.js";
const _sfc_main = {
  name: "profile-buttons",
  props: {
    link: {
      type: Object,
      default: null
    },
    showCallButtonsIfOnline: {
      type: Boolean,
      default: true
    },
    user: {
      type: Object,
      required: true
    }
  },
  data() {
    return {
      subscriptions: {},
      callId: null
    };
  },
  computed: {
    ...mapGetters("user", [
      "uuid",
      "username",
      "profile",
      "loggedInUser",
      "liveLoggedInUser",
      "loggedInUserBusy",
      "liveUsers",
      "hasPermission"
    ]),
    ...mapGetters("config", [
      "configs"
    ]),
    ...mapGetters("chat", [
      "chatBoxLoaded"
    ]),
    liveUser() {
      return this.user && this.liveUsers.find((u) => u.uuid === this.user.uuid);
    },
    isOnline() {
      return !!this.liveUser;
    },
    isUserBusy() {
      return this.isOnline && !!this.liveUser.busy;
    },
    isLoggedIn() {
      return this.user && this.liveLoggedInUser && this.user.uuid === this.liveLoggedInUser.uuid;
    },
    callUuid() {
      return this.callId ? this.callId : this.callId = uuid();
    },
    toUser() {
      return {
        uuid: this.user.uuid,
        username: this.user.username,
        profile: this.user.profile
      };
    },
    fromUser() {
      return {
        uuid: this.loggedInUser.uuid,
        username: this.loggedInUser.username,
        profile: this.loggedInUser.profile
      };
    }
  },
  methods: {
    ...mapActions("user", [
      "UpdateLiveUser"
    ]),
    ...mapActions("chat", [
      "SetActiveChatUser"
    ]),
    setUserStatus(status = false, timerToFalse = null) {
      this.UpdateLiveUser({
        ...this.fromUser,
        busy: status,
        timerToFalse
      });
      this.subscriptions.users.whisper("SetUserStatus", {
        ...this.fromUser,
        busy: status
      });
    },
    showCallingNotification(to) {
      window.callPlaying = playOutgoingCall();
      const alertContent = {
        title: $t("chat.calling", { attribute: to.profile.name }),
        cancelButtonText: $t("chat.cancel"),
        showConfirmButton: false,
        showCancelButton: true,
        position: this.$toastConfig && this.$toastConfig.position ? this.$toastConfig.position.replace("-center", "").replace("start", "left").replace("end", "right") : "bottom-end"
      };
      this.$toasted.clear();
      this.setUserStatus("CALLING");
      window.callTo = to;
      callAlert.fire(alertContent).then((result) => {
        window.callPlaying.pause();
        window.callTo = null;
        if (result.value) {
          this.setUserStatus("ON_CALL");
        } else {
          if (result.dismiss === Swal.DismissReason.cancel) {
            this.setUserStatus(false);
            this.subscriptions.users.whisper("CallCancelled", {
              to: this.toUser,
              from: this.fromUser,
              id: this.callUuid
            });
            this.$toasted.info($t("chat.call_cancelled"), this.$toastConfig.info);
          } else if (result.dismiss === Swal.DismissReason.timer) {
            this.setUserStatus(false);
            this.$toasted.info($t("chat.call_not_answered", { attribute: to.profile.name }), this.$toastConfig.info);
          }
        }
      });
    },
    startCalling() {
      this.$gaEvent("engagement", "startCalling", "ProfileButtons");
      this.$emit("buttonClicked");
      this.showCallingNotification(this.toUser);
      this.callId = uuid();
      window.callUuid = this.callUuid;
      this.subscriptions.users.whisper("IncomingCall", {
        to: this.toUser,
        from: this.fromUser,
        id: this.callUuid
      });
    },
    endCall() {
      this.subscriptions.users.whisper("EndCalling", {
        to: this.toUser,
        from: this.fromUser,
        id: this.callUuid
      });
      this.setUserStatus(false);
      window.callUuid = null;
    },
    startChat() {
      this.$gaEvent("engagement", "startChat", "ProfileButtons");
      this.SetActiveChatUser(this.user);
      EventBus.$emit("START_CHAT_WITH", this.user);
    }
  },
  mounted() {
  },
  created() {
    if (window.Echo && window.EchoOpts) {
      this.subscriptions = {
        users: window.EchoOpts.subscriptions.users
      };
    }
  },
  beforeDestroy() {
  },
  destroyed() {
  }
};
var _sfc_render = function render() {
  var _vm = this, _c = _vm._self._c;
  return _c("div", { staticClass: "buttons-container" }, [_c("div", { staticClass: "buttons-wrapper" }, [_c("div", { staticClass: "btn-group buttons", attrs: { "role": "group" } }, [_vm.link ? _c("router-link", { staticClass: "btn btn-sm btn-light flex-grow-2", attrs: { "to": _vm.link } }, [_vm._v(" " + _vm._s(_vm.$t("user.profile")) + " ")]) : _vm._e(), !_vm.isLoggedIn && (!_vm.showCallButtonsIfOnline || _vm.showCallButtonsIfOnline && _vm.isOnline) && _vm.hasPermission("create-meeting") ? [_c("button", { staticClass: "btn btn-sm btn-light", attrs: { "disabled": _vm.isUserBusy || _vm.loggedInUserBusy }, on: { "click": _vm.startCalling } }, [_c("i", { staticClass: "fas fa-phone-alt" })])] : _vm._e(), _vm.configs.chat && _vm.configs.chat.enabled && _vm.chatBoxLoaded && _vm.uuid !== _vm.user.uuid ? [_c("button", { staticClass: "btn btn-sm btn-light", on: { "click": _vm.startChat } }, [_c("i", { staticClass: "fas fa-comment" })])] : _vm._e()], 2)])]);
};
var _sfc_staticRenderFns = [];
var __component__ = /* @__PURE__ */ normalizeComponent(
  _sfc_main,
  _sfc_render,
  _sfc_staticRenderFns,
  false,
  null,
  null,
  null,
  null
);
const ProfileButtons = __component__.exports;
export {
  ProfileButtons as default
};
//# sourceMappingURL=ProfileButtons.fe85c7b0.js.map
