import { M as Multiselect } from "../vendor/vendor-vue-multiselect.de0a1589.js";
import { E as handleErrors } from "../app.9a8150b2.js";
import { m as mapGetters, i as mapActions } from "../vendor/vendor-core.2a9962eb.js";
import { n as normalizeComponent } from "../_plugin-vue2_normalizer.7b9a2fe2.js";
import "../vendor/vendor-others.d4f8aae2.js";
import "../vendor/vendor-essential.31dae676.js";
import "../vendor/vendor-bootstrap-vue.397f83c5.js";
import "../vendor/vendor-vue-gtag.137cb49d.js";
const _sfc_main = {
  name: "search-tag",
  components: {
    Multiselect
  },
  props: {
    value: {
      type: [Object, Array, String]
    },
    label: {
      type: String,
      default: $t("general.enter_a_tag")
    },
    entityLabel: {
      type: String,
      default: $t("general.tags")
    },
    trackBy: {
      type: String,
      default: "slug"
    },
    showBy: {
      type: String,
      default: "name"
    },
    error: {
      type: String,
      default: null
    },
    taggable: {
      type: Boolean,
      default: true
    },
    searchable: {
      type: Boolean,
      default: true
    },
    allowEmpty: {
      type: Boolean,
      default: true
    },
    disabled: {
      type: Boolean,
      default: false
    },
    required: {
      type: Boolean,
      default: false
    },
    multiple: {
      type: Boolean,
      default: true
    },
    closeOnSelect: {
      type: Boolean,
      default: false
    },
    loading: {
      type: Boolean,
      default: false
    },
    wrapperClasses: {
      type: String
    },
    inputClasses: {
      type: String,
      default: ""
    },
    position: {
      type: String,
      default: "top"
    },
    simple: {
      type: Boolean,
      default: false
    },
    commaSeparatedMultiple: {
      type: Boolean,
      default: false
    },
    addNew: {
      type: String
    },
    addNewModal: {
      type: Boolean,
      default: false
    },
    neededPermission: {
      type: String
    },
    autoFocus: {
      type: Boolean,
      default: false
    },
    optionsLimit: {
      type: Number,
      deafult: 5
    },
    url: {
      type: String,
      default: "tags"
    },
    type: {
      type: String,
      default: ""
    },
    method: {
      type: String,
      default: "get"
    },
    params: {
      type: Object,
      default() {
        return {};
      }
    }
  },
  data() {
    return {
      cbId: "",
      options: [],
      formErrors: {},
      showNewModel: false,
      isLoading: false
    };
  },
  computed: {
    ...mapGetters("config", [
      "uiConfigs"
    ]),
    ...mapGetters("user", [
      "hasPermission"
    ]),
    tags: {
      get() {
        if (this.value && this.simple) {
          if (this.multiple) {
            let val = this.value;
            let toReturn = [];
            if (!_.isArray(val)) {
              val = val.replace(/\s+/g, "").split(",");
            }
            if (this.options.length) {
              toReturn = this.options.filter((o) => val.indexOf(o[this.trackBy]) !== -1);
            } else {
              toReturn = val.map((v) => {
                return {
                  slug: v,
                  name: v.replace("-", " ")
                };
              });
            }
            return toReturn;
          } else {
            return this.options.find((o) => o[this.trackBy] === this.value);
          }
        } else {
          return this.value;
        }
      },
      set(newValue) {
        let toReturn = null;
        if (newValue && this.simple) {
          if (_.isArray(newValue)) {
            toReturn = newValue.map((v) => v[this.trackBy]);
            toReturn = toReturn.join(",");
          } else {
            toReturn = newValue[this.trackBy];
          }
        } else {
          toReturn = newValue;
        }
        this.$emit("input", toReturn);
        this.$emit("update:error", "");
      }
    }
  },
  methods: {
    ...mapActions("common", [
      "Custom"
    ]),
    ...mapActions("config", [
      "SetUiConfig"
    ]),
    searchTags: _.debounce(function(query) {
      if (query.length < 3)
        return false;
      this.isLoading = true;
      this.Custom({
        url: this.url + (this.type ? "?type=" + this.type : ""),
        method: this.method,
        params: {
          q: query,
          ...this.params
        }
      }).then((response) => {
        if (this.tags) {
          this.options = [
            ...this.tags,
            ...response
          ];
        } else {
          this.options = response;
        }
        this.isLoading = false;
      }).catch((error) => {
        if (this.tags) {
          this.options = [
            ...this.tags
          ];
        } else {
          this.options = [];
        }
        this.isLoading = false;
        this.formErrors = handleErrors(error);
      });
    }, 500),
    addTag(newTag) {
      this.$emit("tag", newTag);
      this.focus();
    },
    removeTag(tagToBeRemove) {
      this.tags = this.tags.filter((tag) => {
        return tag[this.trackBy] !== tagToBeRemove[this.trackBy];
      });
    },
    clearSelectedTags() {
      this.tags = null;
      this.options = [];
      this.focus();
    },
    focus() {
      setTimeout(() => {
        if (this.$refs && this.cbId && this.$refs[`multiselect${this.cbId}`]) {
          this.$refs[`multiselect${this.cbId}`].activate();
        }
      }, 500);
    }
  },
  mounted() {
    if (this.autoFocus) {
      this.focus();
    }
  },
  created() {
    this.cbId = Math.random().toString(16).slice(2);
  }
};
var _sfc_render = function render() {
  var _vm = this, _c = _vm._self._c;
  return _c("div", { class: ["multiselect-wrapper", { "not-empty": !!_vm.tags }, { "required": _vm.required }, _vm.wrapperClasses] }, [_c("label", { staticClass: "input-group-material-label" }, [_vm._v(_vm._s(_vm.label) + " "), _vm.required ? _c("span", { staticClass: "required-asterix" }, [_vm._v("*")]) : _vm._e()]), _c("multiselect", { ref: `multiselect${_vm.cbId}`, class: ["input-group-material", _vm.inputClasses], attrs: { "options": _vm.options, "placeholder": _vm.label, "track-by": _vm.trackBy, "label": _vm.showBy, "searchable": _vm.searchable, "show-labels": false, "allow-empty": _vm.allowEmpty, "multiple": _vm.multiple, "close-on-select": _vm.closeOnSelect, "taggable": _vm.taggable, "tag-placeholder": _vm.$t("general.enter_a_tag"), "disabled": _vm.disabled, "loading": _vm.loading || _vm.isLoading, "internal-search": false, "options-limit": _vm.optionsLimit, "tag-position": _vm.position }, on: { "tag": _vm.addTag, "search-change": _vm.searchTags, "remove": _vm.removeTag }, scopedSlots: _vm._u([{ key: "clear", fn: function(props) {
    return [_vm.tags && _vm.allowEmpty ? _c("div", { staticClass: "multiselect__clear", on: { "mousedown": function($event) {
      $event.preventDefault();
      $event.stopPropagation();
      return _vm.clearSelectedTags(props.search);
    } } }) : _vm._e()];
  } }, { key: "noResult", fn: function() {
    return [_c("span", { staticClass: "multiselect__no_result text-muted" }, [_vm._v(_vm._s(_vm.$t("global.could_not_find_any", { attribute: _vm.entityLabel })))])];
  }, proxy: true }, { key: "noOptions", fn: function() {
    return [_c("span", { staticClass: "multiselect__helper text-muted" }, [_vm._v(_vm._s(_vm.$t("general.search_helper_text")))])];
  }, proxy: true }]), model: { value: _vm.tags, callback: function($$v) {
    _vm.tags = $$v;
  }, expression: "tags" } }), _vm._t("errorBlock", function() {
    return [_vm.error ? _c("div", { staticClass: "text-danger invalid-feedback error-block" }, [_vm._v(" " + _vm._s(_vm.error) + " ")]) : _vm._e()];
  })], 2);
};
var _sfc_staticRenderFns = [];
var __component__ = /* @__PURE__ */ normalizeComponent(
  _sfc_main,
  _sfc_render,
  _sfc_staticRenderFns,
  false,
  null,
  null,
  null,
  null
);
const SearchTag = __component__.exports;
export {
  SearchTag as default
};
//# sourceMappingURL=SearchTag.ea233e62.js.map
