import { n as normalizeComponent } from "../../_plugin-vue2_normalizer.7b9a2fe2.js";
const _sfc_main = {
  name: "base-checkbox",
  model: {
    prop: "modelValue",
    event: "change"
  },
  props: {
    modelValue: {
      type: [Array, String, Number, Boolean],
      default: false,
      description: "Whether checkbox is checked"
    },
    disabled: {
      type: Boolean,
      description: "Whether checkbox is disabled"
    },
    inline: {
      type: Boolean,
      description: "Whether checkbox is inline"
    },
    clickStop: {
      type: Boolean,
      default: false
    },
    design: {
      type: String,
      default: "default",
      description: "Button design (e,g primary, danger etc)"
    },
    value: {
      type: [Array, String, Number, Boolean],
      default: true,
      description: "Value to check in an array"
    }
  },
  data() {
    return {
      cbId: "",
      touched: false,
      checkedProxy: false
    };
  },
  computed: {
    shouldBeChecked() {
      if (this.modelValue instanceof Array) {
        this.checkedProxy = this.modelValue.includes(this.value);
      } else {
        this.checkedProxy = this.modelValue === this.value;
      }
      return this.checkedProxy;
    },
    classes() {
      let classes = [
        { "form-check-inline": this.inline },
        this.design && !this.disabled ? `control-${this.design}` : ""
      ];
      return classes;
    }
  },
  methods: {
    doUpdate(isChecked = false) {
      if (!this.touched) {
        this.touched = true;
      }
      if (this.modelValue instanceof Array) {
        let newValue = [...this.modelValue];
        if (isChecked) {
          newValue.push(this.value);
        } else {
          newValue.splice(newValue.indexOf(this.value), 1);
        }
        this.$emit("change", newValue);
      } else {
        this.$emit("change", isChecked ? this.value : false);
      }
    },
    toggleInput() {
      let isChecked = !this.checkedProxy;
      this.doUpdate(isChecked);
    },
    updateInput(event) {
      let isChecked = event.target.checked;
      this.doUpdate(isChecked);
    }
  },
  created() {
    this.cbId = Math.random().toString(16).slice(2);
  }
};
var _sfc_render = function render() {
  var _vm = this, _c = _vm._self._c;
  return _c("div", { staticClass: "custom-control custom-checkbox", class: [_vm.classes, { disabled: _vm.disabled }] }, [_c("input", { staticClass: "custom-control-input", attrs: { "id": _vm.cbId, "type": "checkbox", "disabled": _vm.disabled }, domProps: { "checked": _vm.shouldBeChecked, "value": _vm.value }, on: { "change": _vm.updateInput } }), _vm.clickStop ? [_c("label", { staticClass: "custom-control-label", attrs: { "for": _vm.cbId }, on: { "click": function($event) {
    $event.stopPropagation();
    $event.preventDefault();
    return _vm.toggleInput.apply(null, arguments);
  } } }, [_vm._t("default", function() {
    return [_vm.inline ? _c("span", [_vm._v("\xA0")]) : _vm._e()];
  })], 2)] : [_c("label", { staticClass: "custom-control-label", attrs: { "for": _vm.cbId } }, [_vm._t("default", function() {
    return [_vm.inline ? _c("span", [_vm._v("\xA0")]) : _vm._e()];
  })], 2)]], 2);
};
var _sfc_staticRenderFns = [];
var __component__ = /* @__PURE__ */ normalizeComponent(
  _sfc_main,
  _sfc_render,
  _sfc_staticRenderFns,
  false,
  null,
  null,
  null,
  null
);
const BaseCheckbox = __component__.exports;
export {
  BaseCheckbox as default
};
//# sourceMappingURL=BaseCheckbox.4077396b.js.map
